@@ -9,7 +9,7 @@ if platform.system( ).lower( ) == "windows":
     default_driver = "C"
 elif platform.system( ).lower( ) == "darwin":
     default_path = Path( os.environ[ 'HOME' ], "Desktop" )
-    default_driver = "Macintosh HD"
+    default_driver = Path( os.environ[ 'HOME' ] )
 else:
     pass
 
@@ -27,7 +27,14 @@ def auto_create_folder(
     """
 
     default_path = Path( default_path )
-    default_list = str( default_path ).split( "\\" )
+
+    if platform.system( ).lower( ) == "windows":
+        default_list = str( default_path ).split( "\\" )
+    elif platform.system( ).lower( ) == "darwin":
+        default_list = str( default_path ).split( "/" )
+    else:
+        pass
+
     for elem in default_list:
         if elem == "":
             default_list.remove( "" )
@@ -40,7 +47,13 @@ def auto_create_folder(
     else:
         folder_path = Path( default_path, folder_extend, subfolder_extend )
         # print( folder_path )
-    folder_list = str( folder_path ).split( "\\" )
+
+    if platform.system( ).lower( ) == "windows":
+        folder_list = str( folder_path ).split( "\\" )
+    elif platform.system( ).lower( ) == "darwin":
+        folder_list = str( folder_path ).split( "/" )
+    else:
+        pass
     # print( folder_list )
 
     ##remove default path from full path
@@ -83,12 +96,17 @@ def auto_create_folder_2(
     if platform.system( ).lower( ) == "windows":
         default_path = Path( driver_name + ":/" )
     elif platform.system( ).lower( ) == "darwin":
-        default_path = Path( default_driver + "/" )
+        default_path = Path( default_driver )
     else:
         pass
 
+    if platform.system( ).lower( ) == "windows":
+        default_list = str( default_path ).split( "\\" )
+    elif platform.system( ).lower( ) == "darwin":
+        default_list = str( default_path ).split( "/" )
+    else:
+        pass
 
-    default_list = str( default_path ).split( "\\" )
     for elem in default_list:
         if elem == "":
             default_list.remove( "" )
@@ -101,7 +119,13 @@ def auto_create_folder_2(
     else:
         folder_path = Path( default_path, folder_extend, subfolder_extend )
         # print( folder_path )
-    folder_list = str( folder_path ).split( "\\" )
+
+    if platform.system( ).lower( ) == "windows":
+        folder_list = str( folder_path ).split( "\\" )
+    elif platform.system( ).lower( ) == "darwin":
+        folder_list = str( folder_path ).split( "/" )
+    else:
+        pass
     # print( folder_list )
 
     ##remove default path from full path
